@@ -330,11 +330,14 @@ FREEBSD_KERNEL_VERSION=`uname -U`
 #if  [ $FREEBSD_KERNEL_VERSION -lt 1003507 ] || \
 #    [ $FREEBSD_KERNEL_VERSION -ge 1100000 ] && [ $FREEBSD_KERNEL_VERSION -lt 1100502 ] || \
 #    [ $FREEBSD_KERNEL_VERSION -ge 1200000 ] && [ $FREEBSD_KERNEL_VERSION -lt 1200004 ]
-if  [ $FREEBSD_KERNEL_VERSION -lt 1200056 ]
+if  [ $FREEBSD_KERNEL_VERSION -lt 1200056 ]     # But other bugs remain; see below
 then
     d_uselocale='undef'
 fi
 
+# See https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=265950
+ccflags="${ccflags} -DNO_POSIX_2008_LOCALE"
+
 # https://github.com/Perl/perl5/issues/15984
 # Reported in 11.0-CURRENT with g++-4.8.5:
 # If using g++, the Configure scan for dlopen() fails.
@@ -352,3 +355,24 @@ arm|mips)
   test "$optimize" || optimize='-O2'
   ;;
 esac
+
+# don't modify a supplied -Darchname
+case "$archname" in
+'')
+  cat > UU/archname.cbu <<'EOCBU'
+unamem=`uname -m`
+case "$archname" in
+"$unamem"-*)
+  arch=`uname -p`
+  archname=`echo "$archname" | sed -e "s/^$unamem-/$arch-/"`
+  ;;
+esac
+EOCBU
+  ;;
+esac
+
+# This function on this box has weird behavior.  See
+# https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=255646
+# This has allegedly been fixed, but we can't be sure because of
+# https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=265950
+#d_querylocale='undef'
