@@ -1,4 +1,4 @@
-package builtin 0.010;
+package builtin 0.012;
 
 use strict;
 use warnings;
@@ -27,8 +27,11 @@ builtin - Perl pragma to import built-in utility functions
         trim
         is_tainted
         export_lexically
+        load_module
     );
 
+    use builtin ':5.40';  # most of the above
+
 =head1 DESCRIPTION
 
 Perl provides several utility functions in the C<builtin> package. These are
@@ -85,6 +88,23 @@ Imported symbols can also be removed again by using the C<no> keyword:
     no builtin 'true';
     # true() is no longer aliased from builtin
 
+=head2 Version Bundles
+
+The entire set of builtin functions that were considered non-experimental by a
+version of perl can be imported all at once, by requesting a version bundle.
+This is done by giving the perl release version (without its subversion
+suffix) after a colon character:
+
+    use builtin ':5.40';
+
+The following bundles currently exist:
+
+    Version    Includes
+    -------    --------
+
+    :5.40      true false weaken unweaken is_weak blessed refaddr reftype
+               ceil floor is_tainted trim indexed
+
 =head1 FUNCTIONS
 
 =head2 true
@@ -352,6 +372,25 @@ This must be called at compile time; which typically means during a C<BEGIN>
 block. Usually this would be used as part of an C<import> method of a module,
 when invoked as part of a C<use ...> statement.
 
+=head2 load_module
+
+    load_module($module_name);
+
+This function is currently B<experimental>.
+
+Loads a named module from the inclusion paths (C<@INC>).  C<$module_name> must
+be a string that provides a module name.  It cannot be omitted, and providing
+an invalid module name will result in an exception.  Not providing any argument
+results in a compilation error.  Returns the loaded module's name on success.
+
+The effect of C<load_module>-ing a module is mostly the same as C<require>-ing,
+down to the same error conditions when the module does not exist, does not
+compile, or does not evaluate to a true value.  See also
+L<the C<module_true> feature|feature/"The 'module_true' feature">.
+
+C<load_module> can't be used to require a particular version of Perl, nor can
+it be given a bareword module name as an argument.
+
 =head1 SEE ALSO
 
 L<perlop>, L<perlfunc>, L<Scalar::Util>
