@@ -392,14 +392,7 @@ print $h <<EOH;
 
 #define CLEARFEATUREBITS() (PL_compiling.cop_features = 0)
 
-#define STOREFEATUREBITSHH(hh) \\
-  (hv_stores((hh), "feature/bits", newSVuv(PL_compiling.cop_features)))
-
-#define FETCHFEATUREBITSHH(hh)                              \\
-  STMT_START {                                              \\
-      SV **fbsv = hv_fetchs((hh), "feature/bits", FALSE);   \\
-      PL_compiling.cop_features = fbsv ? SvUV(*fbsv) : 0;   \\
-  } STMT_END
+#define FETCHFEATUREBITSHH(hh) S_fetch_feature_bits_hh(aTHX_ (hh))
 
 #endif /* PERL_CORE or PERL_EXT */
 
@@ -434,7 +427,7 @@ print $h <<EOJ;
 }
 #endif /* PERL_IN_OP_C */
 
-#ifdef PERL_IN_MG_C
+#if defined(PERL_IN_MG_C) || defined(PERL_IN_PP_CTL_C)
 
 #define magic_sethint_feature(keysv, keypv, keylen, valsv, valbool) \\
     S_magic_sethint_feature(aTHX_ (keysv), (keypv), (keylen), (valsv), (valbool))
@@ -491,6 +484,49 @@ print $h <<EOJ;
 }
 #endif /* PERL_IN_MG_C */
 
+/* subject to change */
+struct perl_feature_bit {
+  const char *name;
+  STRLEN namelen;
+  U32 mask;
+};
+
+#ifdef PERL_IN_PP_CTL_C
+
+static const struct perl_feature_bit
+PL_feature_bits[] = {
+EOJ
+for my $key (sort keys %feature) {
+    my $val = $feature{$key};
+    print $h <<EOJ;
+    {
+        /* feature $key */
+        "feature_$val",
+        STRLENs("feature_$val"),
+        FEATURE_\U$val\E_BIT
+    },
+EOJ
+}
+
+print $h <<EOJ;
+    { NULL, 0, 0U }
+};
+
+PERL_STATIC_INLINE void
+S_fetch_feature_bits_hh(pTHX_ HV *hh) {
+    PL_compiling.cop_features = 0;
+
+    const struct perl_feature_bit *fb = PL_feature_bits;
+    while (fb->name) {
+        SV **svp = hv_fetch(hh, fb->name, (I32)fb->namelen, 0);
+        if (svp && SvTRUE(*svp))
+               PL_compiling.cop_features |= fb->mask;
+        ++fb;
+    }
+}
+
+#endif
+
 #endif /* PERL_FEATURE_H_ */
 EOJ
 
@@ -502,7 +538,7 @@ read_only_bottom_close_and_rename($h);
 
 __END__
 package feature;
-our $VERSION = '1.83';
+our $VERSION = '1.85';
 
 FEATURES
 
@@ -855,7 +891,7 @@ for the exceptions listed below.
 The perl built-in filehandles C<STDIN>, C<STDOUT>, C<STDERR>, C<DATA>,
 C<ARGV>, C<ARGVOUT> and the special C<_> are always enabled.
 
-This feature is enabled under this name from Perl 5.34 onwards.  In
+This feature is available under this name from Perl 5.34 onwards.  In
 previous versions it was simply on all the time.
 
 You can use the L<bareword::filehandles> module on CPAN to disable
@@ -1336,6 +1372,19 @@ no effect.  Feature bundles are guaranteed to be the same for all sub-versions.
   use feature ":5.14.0";    # same as ":5.14"
   use feature ":5.14.1";    # same as ":5.14"
 
+You can also do:
+
+  use feature ":all";
+
+or
+
+  no feature ":all";
+
+but the first may enable features in a later version of Perl that
+change the meaning of your code, and the second may disable mechanisms
+that are part of Perl's current behavior that have been turned into
+features, just as C<indirect> and C<bareword_filehandles> were.
+
 =head1 IMPLICIT LOADING
 
 Instead of loading feature bundles by name, it is easier to let Perl do
